@@ -41,6 +41,8 @@
 
 #define KBOOKMARKS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KBOOKMARKS_NO_DEPRECATED) && !defined(KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KBOOKMARKS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KBOOKMARKS_NO_DEPRECATED
-#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
+#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54200
 #endif
 #ifdef KBOOKMARKS_NO_DEPRECATED_WARNINGS
 #  define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x57100
+#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x54200
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KBOOKMARKS_DEPRECATED
-#  define KBOOKMARKS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KBOOKMARKS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KBOOKMARKS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -119,21 +121,7 @@
 #else
 #  define KBOOKMARKS_DEPRECATED_VERSION_5_65(text)
 #endif
-
-#if KBOOKMARKS_DEPRECATED_WARNINGS_SINCE >= 0x54500
-#  define KBOOKMARKS_DEPRECATED_VERSION_5_69(text) KBOOKMARKS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KBOOKMARKS_DEPRECATED_VERSION_5_69(text)
-#endif
 #define KBOOKMARKS_DEPRECATED_VERSION_5(minor, text)      KBOOKMARKS_DEPRECATED_VERSION_5_##minor(text)
 #define KBOOKMARKS_DEPRECATED_VERSION(major, minor, text) KBOOKMARKS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KBOOKMARKS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KBOOKMARKS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KBOOKMARKS_DEPRECATED_VERSION(major, minor, text)
-#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KBOOKMARKS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KBOOKMARKS_EXPORT_H */
